# Music Thumbnail
## Installing
```
pip install TMFrame
```
## Usage
<details>
<summary>FULL</summary>
<br>

```bash
$ python3 -m TMFrame --image example/maxresdefault.jpg --title="It Ain't Me" --artist="Kygo & Selena Gomez" --color='[206, 0, 66]' --out=example/result.jpg

```

</details>

<details>
<summary>CUSTOM</summary>
<br>

```bash
$ python3 -m TMFrame --image=example/maxresdefault.jpg --title="It Ain't Me" --artist="Kygo & Selena Gomez" --color='[206, 0, 66]' --out=example/result.jpg --width=500

```

</details>

# RESULT

<details>
<summary>BEFORE</summary>
<br>
<img src="https://raw.githubusercontent.com/krypton-byte/TMFrame/master/example/maxresdefault.jpg">
</details>
<details>
<summary>AFTER</summary>
<br>
<img src="https://raw.githubusercontent.com/krypton-byte/TMFrame/master/example/result.jpg">
</details>

Thanks to <a href="https://github.com/plucyvrz">plucyvrz</a> for making the frame
